## ----setup, include=FALSE------------------------------------------------
#setwd("/Users/Xavi/Dropbox/xavi-umh/docencia/")
#setwd("~/Dropbox/xavi-umh/docencia/TEIM/2016-2017/temas/tema1")
setwd("~/Dropbox/xavi-umh/docencia/SERIES/2018/tema 03")

 library(knitr)
 library(rmarkdown)
 library(xtable)
 library(highlight)
library(stargazer)
library(texreg)
library(caret)
options(xtable.comment = FALSE)
knitr::opts_chunk$set(width.cutoff=100, fig.width=8, fig.height=8, size="normalsize", warning=FALSE, message=FALSE, echo=FALSE, tidy=TRUE, width=60)
knitr::opts_chunk$set(tidy.opts=list(width.cutoff=60))
opts_knit$set(root.dir = "~/Dropbox/xavi-umh/docencia/SERIES/2018/TEMA 03")

## ------------------------------------------------------------------------
library(grofit)
x <- 1:30
y <- gompertz(x, 10, 2, 5)
plot(x,y, type="l")
title("Ejemplo de Curva de Gompertz ")

## ---- echo=TRUE----------------------------------------------------------
library(forecast)
Acf(wineind)

## ---- echo=TRUE----------------------------------------------------------
Pacf(wineind)

## ---- echo=TRUE----------------------------------------------------------
taperedacf(wineind, nsim=50)

## ---- echo=TRUE----------------------------------------------------------
taperedpacf(wineind, nsim=50)

## ---- echo=TRUE----------------------------------------------------------
library(RCurl)
## get CO2 data from Mauna Loa observatory
ww1 <- "ftp://aftp.cmdl.noaa.gov/products/"
ww2 <- "trends/co2/co2_mm_mlo.txt"
CO2 <- read.table(text=getURL(paste0(ww1,ww2)))[,c(1,2,5)]
## assign better column names
colnames(CO2) <- c("year","month","ppm")

## ------------------------------------------------------------------------
kable(head(CO2), caption="atmospheric concentration of CO2")

## ---- echo=TRUE, tidy=FALSE----------------------------------------------
## create a time series (ts) object from the CO2 data
co2 <- ts(data=CO2$ppm, frequency=12,
              start=c(CO2[1,"year"],CO2[1,"month"]))
## plot the ts
plot.ts(co2, ylab=expression(paste("CO"[2]," (ppm)")))

## ---- echo=TRUE, eval=FALSE, tidy=FALSE----------------------------------
## ## get N Hemisphere land & ocean temperature anomalies from NOAA
## Temp <- read_csv("https://www.ncdc.noaa.gov/cag/global/time-series
##                      /nhem/land_ocean/p12/12/1880-2014.csv" , skip = 4)
## ## create ts object
## tmp <- ts(data=Temp$Value, frequency=12, start=c(1880,1))

## ---- echo=FALSE---------------------------------------------------------
## get N Hemisphere land & ocean temperature anomalies from NOAA
library(readr)
Temp <- read_csv("https://www.ncdc.noaa.gov/cag/global/time-series/nhem/land_ocean/p12/12/1880-2014.csv" , skip = 4)
## create ts object
tmp <- ts(data=Temp$Value, frequency=12, start=c(1880,1))

## ------------------------------------------------------------------------
kable(head(tmp))

## ---- ECHO=TRUE----------------------------------------------------------
## intersection (only overlapping times)
datI <- ts.intersect(co2,tmp)
## dimensions of common-time data
dim(datI)
## plot the ts
plot(datI, main="", yax.flip=TRUE)

## ---- echo=TRUE----------------------------------------------------------
co2.decomp <- decompose(co2)
plot(co2.decomp, yax.flip=TRUE)

## ------------------------------------------------------------------------
tmp.decomp <- decompose(tmp)
plot(tmp.decomp, yax.flip=TRUE)

## ---- echo=TRUE----------------------------------------------------------
## twice-difference the CO2 data
co2.D2 <- diff(co2, differences=2)
## plot the differenced data
plot(co2.D2, ylab=expression(paste(nabla^2,"CO"[2])))

## ---- echo=TRUE, tidy=FALSE----------------------------------------------
## difference the differenced CO2 data
co2.D2D12 <- diff(co2.D2, lag=12)
## plot the newly differenced data
plot(co2.D2D12,
       ylab=expression(paste(nabla,"(",nabla^2,"CO"[2],")")))

## ---- echo=TRUE----------------------------------------------------------
## correlogram of the CO2 data
acf(co2, lag.max=36)

## ---- echo=TRUE----------------------------------------------------------
## correlogram of the CO2 data
pacf(co2, lag.max=36)

## ---- echo=TRUE----------------------------------------------------------
plot.acf <- function(ACFobj) {
rr <- ACFobj$acf[-1]
kk <- length(rr)
nn <- ACFobj$n.used
plot(seq(kk),rr,type="h",lwd=2,yaxs="i",xaxs="i",
ylim=c(floor(min(rr)),1),xlim=c(0,kk+1),
xlab="Lag",ylab="Correlation",las=1)
abline(h=-1/nn+c(-2,2)/sqrt(nn),lty="dashed",col="blue")
abline(h=0)
}

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## ## create sine wave
## tt <- sin(2*pi*seq(nn)/12)
## ## set up plot area
## par(mfrow=c(1,2))
## ## plot line
## plot.ts(tt, ylab=expression(italic(x[t])))
## ## get ACF
## sine.acf <- acf(tt, plot=FALSE)
## ## plot ACF
## plot.acf(sine.acf)

## ---- echo=FALSE, eval=TRUE----------------------------------------------
## create sine wave
nn <- 100
tt <- seq(nn)
tt <- sin(2*pi*seq(nn)/12)
## set up plot area
par(mfrow=c(1,2))
## plot line
plot.ts(tt, ylab=expression(italic(x[t])))
## get ACF
sine.acf <- acf(tt, plot=FALSE)
## plot ACF
plot.acf(sine.acf)

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## ## create sine wave with trend
## tt <- sin(2*pi*seq(nn)/12) - seq(nn)/50
## ## set up plot area
## par(mfrow=c(1,2))
## ## plot line
## plot.ts(tt, ylab=expression(italic(x[t])))
## ## get ACF
## sili.acf <- acf(tt, plot=FALSE)
## ## plot ACF
## plot.acf(sili.acf)

## ---- echo=FALSE, eval=TRUE----------------------------------------------
## create sine wave with trend
tt <- sin(2*pi*seq(nn)/12) - seq(nn)/50
## set up plot area
par(mfrow=c(1,2))
## plot line
plot.ts(tt, ylab=expression(italic(x[t])))
## get ACF
sili.acf <- acf(tt, plot=FALSE)
## plot ACF
plot.acf(sili.acf)

## ---- echo=TRUE----------------------------------------------------------
plot.pacf <- function(PACFobj) {
rr <- PACFobj$acf
kk <- length(rr)
nn <- PACFobj$n.used
plot(seq(kk),rr,type="h",lwd=2,yaxs="i",xaxs="i",
     ylim=c(floor(min(rr)),1),xlim=c(0,kk+1),
xlab="Lag",ylab="PACF",las=1)
abline(h=-1/nn+c(-2,2)/sqrt(nn),lty="dashed",col="blue")
abline(h=0)
}

## ---- echo=TRUE----------------------------------------------------------
## PACF of the CO2 data
co2.pacf <- pacf(co2)
## correlogram of the CO2 data
plot.acf(co2.pacf)

## ---- echo=TRUE----------------------------------------------------------
set.seed(123)
## random normal variates
GWN <- rnorm(n=100, mean=5, sd=0.2)
## random Poisson variates
PWN <- rpois(n=50, lambda=20)

## ---- eval=FALSE, echo=TRUE----------------------------------------------
## ## set up plot region
## par(mfrow=c(1,2))
## ## plot normal variates with mean
## plot.ts(GWN)
## abline(h=5, col="blue", lty="dashed")
## ## plot Poisson variates with mean
## plot.ts(PWN)
## abline(h=20, col="blue", lty="dashed")

## ---- eval=TRUE, echo=FALSE----------------------------------------------
## set up plot region
par(mfrow=c(1,2))
## plot normal variates with mean
plot.ts(GWN)
abline(h=5, col="blue", lty="dashed")
## plot Poisson variates with mean
plot.ts(PWN)
abline(h=20, col="blue", lty="dashed")

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## ## set up plot region
## par(mfrow=c(1,2))
## ## plot normal variates with mean
## acf(GWN, main="", lag.max=20)
## ## plot Poisson variates with mean
## acf(PWN, main="", lag.max=20)

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## ## set up plot region
## par(mfrow=c(1,2))
## ## plot normal variates with mean
## acf(GWN, main="", lag.max=20)
## ## plot Poisson variates with mean
## acf(PWN, main="", lag.max=20)

## ---- echo=TRUE----------------------------------------------------------
## set random number seed
set.seed(123)
## length of time series
TT <- 100
## initialize {x_t} and {w_t}
xx <- ww <- rnorm(n=TT, mean=0, sd=1)
## compute values 2 thru TT
for(t in 2:TT) { xx[t] <- xx[t-1] + ww[t] }

## ------------------------------------------------------------------------
## setup plot area
par(mfrow=c(1,2))
## plot line
plot.ts(xx, ylab=expression(italic(x[t])))
## plot ACF
plot.acf(acf(xx, plot=FALSE))

## ------------------------------------------------------------------------
## simulate RW
x2 <- cumsum(ww)
## setup plot area
par(mfrow=c(1,2))
## plot 1st RW
plot.ts(xx, ylab=expression(italic(x[t])))
title(" 1st RW")
## plot 2nd RW
plot.ts(x2, ylab=expression(italic(x[t])))
title(" 2nd RW")


